MemoryCache

Struct MemoryCache 

pub struct MemoryCache { /* private fields */ }
Lean in-process cache store adapter for local development and tests.

Implementations

Source

impl MemoryCache

pub fn new(prefix: Option<String>, max_entries: Option<usize>) -> Self

Create an empty in-memory cache.

pub fn new_with_clock( prefix: Option<String>, max_entries: Option<usize>, clock: impl Fn() -> Instant + Send + Sync + 'static, ) -> Self

Create an in-memory cache with an injected clock.

This is primarily useful for deterministic tests and simulations that need to advance cache expiry without sleeping.